@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ConfigDefs.pl 3761 2006-10-30 22:28:25Z sysjkf $
+#   $Id: ConfigDefs.pl 3833 2007-01-30 18:20:13Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -205,6 +205,7 @@ virusscan			= virusscanning
 warnsenders			= notifysenders
 warnvirussenders		= notifysendersofviruses
 warnnamesenders			= notifysendersofblockedfilenamesorfiletypes
+warnsizesenders                 = notifysendersofblockedsizeattachments
 warnothersenders		= notifysendersofotherblockedcontent
 webbugurl			= webbugreplacement
 webbugwhitelist			= ignoredwebbugfilenames
@@ -409,6 +410,7 @@ warningisattachment	1	no	0	yes	1
 WarnSenders		1	no	0	yes	1
 WarnVirusSenders	0	no	0	yes	1
 WarnNameSenders		1	no	0	yes	1
+WarnSizeSenders		0	no	0	yes	1
 WarnOtherSenders	1	no	0	yes	1
 
 [First,File]
