@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: CustomConfig.pm,v 1.3.2.36 2006/01/14 21:56:52 jkf Exp $
+#   $Id: CustomConfig.pm 3638 2006-06-17 20:28:07Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ no  strict 'subs'; # Allow bare words for parameter %'s
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.3.2.36 $, 10;
+$VERSION = substr q$Revision: 3638 $, 10;
 
 #
 # These are the custom functions that you can write to produce a value
@@ -961,7 +961,7 @@ sub IPBlock {
       IPBunlockclose($LockFileH);
       return 0;
     }
-    MailScanner::Log::InfoLog("IPBlock: Adding block for %s", $ip);
+    MailScanner::Log::NoticeLog("IPBlock: Adding block for %s", $ip);
     $AccessDB{$ip} = $Refusal;
     $AccessDB{$hostname} = $Refusal;
     $donealready = 1; # Mark it so we don't try to waste CPU setting it twice
@@ -985,7 +985,7 @@ sub IPBopenlock {
   if (open($fh, $fn)) {
     flock($fh, LOCK_EX);
   } else {
-    MailScanner::Log::InfoLog("Could not open file $fn: %s", $!);
+    MailScanner::Log::NoticeLog("Could not open file $fn: %s", $!);
   }
 }
 
