@@ -1030,27 +1030,35 @@ sub DeleteRecipients {
 
 sub KickMessage {
   my $pid;
+  my($messages) = @_;
+  my(@ids, @ThisBatch);
+  # Build a list @ids of all the message ids
+  foreach (values(%{$messages})) {
+    push @ids, split(" ", $_);
+  }
 
-  ## My original implementation
-  #my(@ids) = @_;
-  #my($idlist);
-  #$idlist = join(' ', @ids);
-  #$idlist .= ' &' if MailScanner::Config::Value('deliverinbackground');
-  ##print STDERR "About to do \"Sendmail2 -Mc $idlist\"\n";
-  #system(MailScanner::Config::Value('sendmail2') . ' -Mc ' . $idlist);
+  while(@ids) {
+    @ThisBatch = splice @ids, $[, 30;
 
-  # JJH's version
-  if(MailScanner::Config::Value('deliverinbackground')) {
-    # fork twice so that we don't have to reap :-)
-    $pid = fork;
-    # jjh 2004-03-12 don't waitpid here, too slow.
-    #waitpid $pid, 0 if $pid > 0;
-    return if $pid > 0 or not defined $pid;
-    $pid = fork;
-    exit if $pid > 0 or not defined $pid;
-    exec(split(/ +/, MailScanner::Config::Value('sendmail2')), '-Mc', @_);
-  } else {
-    system(split(/ +/, MailScanner::Config::Value('sendmail2')), '-Mc', @_);
+    # This code is the simpler version of the #JJH code below here.
+    my $idlist = join(' ', @ThisBatch);
+    $idlist .= ' &' if MailScanner::Config::Value('deliverinbackground');
+    print STDERR "About to do \"Sendmail2 -Mc $idlist\"\n";
+    system(MailScanner::Config::Value('sendmail2') . ' -Mc ' . $idlist);
+
+    #JJH # JJH's version
+    #JJH if(MailScanner::Config::Value('deliverinbackground')) {
+      #JJH # fork twice so that we don't have to reap :-)
+      #JJH $pid = fork;
+      #JJH # jjh 2004-03-12 don't waitpid here, too slow.
+      #JJH #waitpid $pid, 0 if $pid > 0;
+      #JJH return if $pid > 0 or not defined $pid;
+      #JJH $pid = fork;
+      #JJH exit if $pid > 0 or not defined $pid;
+      #JJH exec(split(/ +/, MailScanner::Config::Value('sendmail2')), '-Mc', @ThisBatch);
+    #JJH } else {
+      #JJH system(split(/ +/, MailScanner::Config::Value('sendmail2')), '-Mc', @ThisBatch);
+    #JJH }
   }
 
 }
