@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Log.pm 3665 2006-07-21 09:40:06Z sysjkf $
+#   $Id: Log.pm 3724 2006-09-23 15:30:45Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -67,11 +67,11 @@ sub Start {
     # This was too simple and didn't work on some Solaris and IRIX systems
     #eval { Sys::Syslog::setlogsock('unix'); }; # This may fail!
     eval {
-      if ($^O !~ /solaris|sunos|irix/i) {
+      if ($^O =~ /solaris|sunos|irix/i) {
+        Sys::Syslog::setlogsock('udp');
+      } else {
         Sys::Syslog::setlogsock('unix');
-      } # else {
-        # Sys::Syslog::setlogsock('stream');
-      # }
+      }
     };
     eval { Sys::Syslog::openlog($name, 'pid, nowait', $facility); };
   }
