@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MCPMessage.pm,v 1.1.2.29 2006/01/15 17:55:30 jkf Exp $
+#   $Id: MCPMessage.pm 3638 2006-06-17 20:28:07Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ install MIME::Decoder::UU 'uuencode';
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.29 $, 10;
+$VERSION = substr q$Revision: 3638 $, 10;
 
 # Is this message spam? Try to build the spam report and store it in
 # the message.
@@ -475,18 +475,18 @@ sub HandleMCPBounce {
   $filename = "";
   #if ($this->{isrblspam} && !$this->{issaspam}) {
   #  $filename = MailScanner::Config::Value('senderrblspamreport', $this);
-  #  MailScanner::Log::InfoLog("Spam Actions: (RBL) Bounce to %s", $from)
+  #  MailScanner::Log::NoticeLog("Spam Actions: (RBL) Bounce to %s", $from)
   #    if MailScanner::Config::Value('logspam');
   #} elsif ($this->{issaspam} && !$this->{isrblspam}) {
   if ($this->{issamcp}) {
     $filename = MailScanner::Config::Value('sendersamcpreport', $this);
-    MailScanner::Log::InfoLog("MCP Actions: (SpamAssassin) Bounce to %s",
+    MailScanner::Log::NoticeLog("MCP Actions: (SpamAssassin) Bounce to %s",
                               $from)
       if MailScanner::Config::Value('logmcp');
   }
   #if ($filename eq "") {
   #  $filename = MailScanner::Config::Value('senderbothmcpreport', $this);
-  #  MailScanner::Log::InfoLog("Spam Actions: (RBL,SpamAssassin) Bounce to %s",
+  #  MailScanner::Log::NoticeLog("Spam Actions: (RBL,SpamAssassin) Bounce to %s",
   #                            $from)
   #    if MailScanner::Config::Value('logspam');
   #}
