@@ -54,7 +54,7 @@ $VERSION = substr q$Revision: 877 $, 10;
 sub TellAbout {
   my(@messages) = @_;
 
-  my(@idlist, @ThisBatch, $message);
+  my(@idlist, @ThisBatch, $message, %OutQueues);
 
   return unless @messages;
 
@@ -63,18 +63,22 @@ sub TellAbout {
 
   # Build a list of the messages we actually have to tell sendmail about
   foreach $message (@messages) {
-    push @idlist, $message->{id}
+    $OutQueues{MailScanner::Config::Value('outqueuedir', $message)} .= " " . $message->{id}
+    #push @idlist, $message->{id}
       unless MailScanner::Config::Value('deliverymethod', $message) eq 'queue';
   }
 
   # If there are no "kicking" messages in the list, just get out
-  return unless @idlist;
+  #return unless @idlist;
+  return unless %OutQueues;
 
   # Deliver up to 20 messages per invocation
-  while(@idlist) {
-    @ThisBatch = splice @idlist, $[, 20;
-    MailScanner::Sendmail::KickMessage(@ThisBatch);
-  }
+  #while(@idlist) {
+  #  @ThisBatch = splice @idlist, $[, 20;
+  #  MailScanner::Sendmail::KickMessage(@ThisBatch);
+  #}
+  # Now takes a hash of queues-->space-separated string of message ids
+  MailScanner::Sendmail::KickMessage(\%OutQueues);
 }
 
 
