@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MessageBatch.pm 3780 2006-11-29 13:43:10Z sysjkf $
+#   $Id: MessageBatch.pm 3832 2007-01-30 18:01:19Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ use Time::HiRes qw ( time );
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3780 $, 10;
+$VERSION = substr q$Revision: 3832 $, 10;
 
 my $maxcleanbytes    = 0;
 my $maxcleanmessages = 0;
@@ -862,8 +862,12 @@ sub WarnSenders {
                   $warnviruses;
     $reasons++ if $message->{nameinfected}  &&
                   MailScanner::Config::Value('warnnamesenders', $message);
-    $reasons++ if ($message->{otherinfected} || $message->{sizeinfected}) &&
+    $reasons++ if $message->{sizeinfected} &&
+                  MailScanner::Config::Value('warnsizesenders', $message);
+    $reasons++ if $message->{otherinfected} &&
                   MailScanner::Config::Value('warnothersenders', $message);
+    #$reasons++ if ($message->{otherinfected} || $message->{sizeinfected}) &&
+    #              MailScanner::Config::Value('warnothersenders', $message);
     next if $reasons==0;
 
     $message->WarnSender();
