@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: PFDiskStore.pm 3274 2005-12-29 16:25:35Z jkf $
+#   $Id: PFDiskStore.pm 3768 2006-11-07 19:10:54Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ use MailScanner::Config;
 use vars qw($VERSION @DeletesPending);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3274 $, 10;
+$VERSION = substr q$Revision: 3768 $, 10;
 
 # List of pending delete operations so we can clear up properly when killed
 @DeletesPending = ();
@@ -59,7 +59,7 @@ $VERSION = substr q$Revision: 3274 $, 10;
 #use vars qw($VERSION);
 #
 #### The package version, both in 1.23 style *and* usable by MakeMaker:
-#$VERSION = substr q$Revision: 3274 $, 10;
+#$VERSION = substr q$Revision: 3768 $, 10;
 
 # Attributes are
 #
@@ -465,27 +465,119 @@ sub ReadBody {
   my($body, $max) = @_;
 
   my $line;
+  my $lastlineread = undef;
 
   my $b = Body->new( $this->{inhdhandle} );
-  if ($b) {
-    # Was the $max parameter used at all?
-    if ($max) {
-      my $size = 0;
-      $b->Start();
-      while(defined($line = $b->Next()) && $size<$max) {
-        push @{$body}, $line . "\n";
-        $size += length($line)+1;
-      }
-      $b->Done();
-    } else {
-      # No $max passed, so do as before
-      $b->Start();
-      while(defined($line = $b->Next())) {
-        push @{$body}, $line . "\n";
-      }
-      $b->Done();
+  return unless $b;
+
+  # Restraint is disabled, do the whole message.
+  print "max message size is '$max'\n";
+  unless ($max) {
+    while(defined($lastlineread = $b->Next())) {
+      # End of line characters are already there, so don't add them
+      push @{$body}, $lastlineread . "\n";
+      #print STDERR "Line read is ****" . $_ . "****\n";
     }
+    $b->Done();
+    return;
   }
+
+  my @configwords = split(" ", $max);
+  $max = $configwords[0];
+  $max =~ s/_//g;
+  $max =~ s/k$/000/ig;
+  $max =~ s/m$/000000/ig;
+  $max =~ s/g$/000000000/ig;
+  #print STDERR "Words are " . join(',',@configwords) . "\n";
+
+  # Read the body up to the limit
+  my($line, $size);
+  $size = 0;
+
+  while(defined($line = $b->Next()) && $size<$max) {
+    push @{$body}, $line . "\n";
+    $size += length($line);
+    #print STDERR "Line read2 is ****" . $line . "****\n";
+  }
+  $lastlineread = $line;
+
+  #print STDERR "Initially read $size bytes\n";
+
+  # Handle trackback -- This is the tricky one
+  if ($configwords[1] =~ /tr[ua]/i) {
+    #print STDERR "Trackback:\n";
+    while (${@{$body}}[scalar(@{$body})-1] !~ /^\s*$/) {
+      print "Line is ****" . ${@{$body}}[scalar(@{$body})-1] . "****\n";
+      pop @{$body};
+      #print STDERR ".";
+    }
+    #print STDERR "\n";
+    $b->Done();
+    return;
+  }
+
+  # Handle continue
+  if ($configwords[1] =~ /con/i) {
+    #print STDERR "Continue:\n";
+    my $maxsizes = 0;
+    my $maxsize  = 0;
+
+    # Work out the number they have put in the .conf line after "continue"
+    $maxsizes = $configwords[2] if $configwords[2] =~ /^[0-9]/;
+    $maxsizes =~ s/_//g;
+    if ($maxsizes =~ s/k$//i) {
+      $maxsize = $maxsizes * 1000;
+    } elsif ($maxsizes =~ s/m$//i) {
+      $maxsize = $maxsizes * 1000000;
+    } elsif ($maxsizes =~ s/g$//i) {
+      $maxsize = $maxsizes * 1000000000;
+    } elsif ($maxsizes =~ s/[^0-9]*//g) {
+      $maxsize = $maxsizes;
+    }
+
+    # Value provided in .conf is the number of extra bytes to read.
+    $maxsize += $max;
+    #print STDERR "Maxsize = $maxsize\n";
+
+    # Now need to read extra bytes up to $maxsize bytes
+    while(defined $lastlineread && $lastlineread !~ /^\s*$/) {
+      #print "Continue added '$lastlineread'\n";
+      $size += length($lastlineread);
+      last if $size > $maxsize;
+      push @{$body}, $lastlineread . "\n";
+      $lastlineread = $b->Next();
+      #print STDERR "Added $lastlineread";
+    }
+
+    $b->Done();
+    return;
+  }
+
+#****************************************************************
+#    # Was the $max parameter used at all?
+#    if ($max) {
+#      my $size = 0;
+#      $b->Start();
+#      while(defined($line = $b->Next()) && $size<$max) {
+#        push @{$body}, $line . "\n";
+#        $size += length($line)+1;
+#      }
+#      # Continue copying until we hit a blank line, gives SA a complete
+#      # encoded attachment
+#      #while(defined $line) {
+#      #  $line = $b->Next();
+#      #  last if $line =~ /^\s+$/;
+#      #  push @{$body}, $line . "\n" if defined $line;
+#      #}
+#      $b->Done();
+#    } else {
+#      # No $max passed, so do as before
+#      $b->Start();
+#      while(defined($line = $b->Next())) {
+#        push @{$body}, $line . "\n";
+#      }
+#      $b->Done();
+#    }
 }
 
 
