@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Postfix.pm 3727 2006-09-24 11:18:34Z sysjkf $
+#   $Id: Postfix.pm 3830 2007-01-30 09:32:49Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3727 $, 10;
+$VERSION = substr q$Revision: 3830 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -921,22 +921,28 @@ sub new {
 
   # Send an I down the FIFO to the Postfix queue manager, so that it reads
   # its incoming queue.
+  # I am passed a hash of queues --> space-separated string of message ids
   sub KickMessage {
-    my(@ids) = @_;
-    my($idlist);
+    my($queue2ids) = @_;
+    my($queue);
 
-    # Using the spool directory with the last element chopped off,
-    # find the public directory wth the qmgr FIFO in it. Send an I
-    # to that FIFO.
-    my $public = MailScanner::Config::Value('outqueuedir');
-    $public =~ s/[^\/]+$/public/;
-    my $fh = new FileHandle;
-    $fh->open(">$public/qmgr") or
-      MailScanner::Log::WarnLog("KickMessage failed as couldn't write to " .
-                                "%s, %s", "$public/qmgr", $!);
-    print $fh "I";
-    $fh->close;
+    # Do a kick for every queue that contains some message ids
+    foreach $queue (keys %$queue2ids) {
+      next unless $queue2ids->{$queue};
 
+      # Using the spool directory with the last element chopped off,
+      # find the public directory wth the qmgr FIFO in it. Send an I
+      # to that FIFO.
+      my $public = $queue;
+      $public =~ s/[^\/]+$/public/;
+      next unless $public; # Sanity checking!
+      my $fh = new FileHandle;
+      $fh->open(">$public/qmgr") or
+        MailScanner::Log::WarnLog("KickMessage failed as couldn't write to " .
+                                  "%s, %s", "$public/qmgr", $!);
+      print $fh "I";
+      $fh->close;
+    }
     return 0;
   }
 
