@@ -5,7 +5,7 @@
 #   OpenProtect - Server Side E-Mail Protection	
 #   Copyright (C) 2003 Opencomputing Technologies
 #
-#   $Id: Qmail.pm,v 1.1.2.10 2005/11/20 14:53:42 jkf Exp $
+#   $Id: Qmail.pm 3638 2006-06-17 20:28:07Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.1.2.10 $, 10;
+$VERSION = substr q$Revision: 3638 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -812,7 +812,7 @@ sub new {
     } while $batchempty; # Keep trying until we get something
 
     # Log the number of invalid messages found
-    MailScanner::Log::InfoLog("New Batch: Found invalid queue files: %s",
+    MailScanner::Log::NoticeLog("New Batch: Found invalid queue files: %s",
                               $invalidfiles)
       if $invalidfiles;
     # Log the size of the queue if it is more than 1 batch
