@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SA.pm 3553 2006-05-09 19:51:10Z sysjkf $
+#   $Id: SA.pm 3810 2007-01-22 12:09:57Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ use Compress::Zlib;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3553 $, 10;
+$VERSION = substr q$Revision: 3810 $, 10;
 
 # Attributes are
 #
@@ -524,10 +524,21 @@ sub Checks {
       #print STDERR "Cache hit for " . $message->{id} . "\n";
       MailScanner::Log::InfoLog("SpamAssassin cache hit for message %s", $message->{id});
       # Read the cache result and update the timestamp *****
-      ($SAResult, $HighScoring, $SAHitList, $SAScore, $SAReport) =
-      ($cachehash->{sasaysspam}, $cachehash->{sahighscoring},
-       uncompress($cachehash->{saheader}),   $cachehash->{sascore},
-       uncompress($cachehash->{salongreport}));
+      #($SAResult, $HighScoring, $SAHitList, $SAScore, $SAReport) =
+      #($cachehash->{sasaysspam}, $cachehash->{sahighscoring},
+      # uncompress($cachehash->{saheader}),   $cachehash->{sascore},
+      # uncompress($cachehash->{salongreport}));
+#     ($SAResult, $HighScoring, $SAHitList, $SAScore, $SAReport) =
+#     ($cachehash->{sasaysspam}, $cachehash->{sahighscoring},
+#      uncompress($cachehash->{saheader}),   $cachehash->{sascore},
+#      uncompress($cachehash->{salongreport}));
+      ($SAHitList, $SAScore, $SAReport) = ( 
+        uncompress($cachehash->{saheader}),   $cachehash->{sascore},
+        uncompress($cachehash->{salongreport})
+      );
+
+      # calculate SAResult and HighScoring from actual message
+      ($SAResult, $HighScoring) = SATest_spam( $message, $GSHits, $SAScore );
 
       # Log the fact we got it from the cache. Must not add the "cached"
       # word on the front here or it will be put into the cache itself!
@@ -863,7 +874,6 @@ sub SAForkAndTest {
     if $@ and $@ !~ /Command Timed Out/;
 
   # In which case any failures must be the alarm
-  #if ($@ or $pid>0) {
   if ($pid>0) {
     $pid2delete = $pid;
     my $maxfailures = MailScanner::Config::Value('maxspamassassintimeouts');
@@ -939,21 +949,51 @@ sub SAForkAndTest {
   MailScanner::Log::DebugLog("SpamAssassin returned $PipeReturn");
 
   #$PipeReturn = $PipeReturn>>8;
-  if ($SAHits && ($SAHits+$GSHits>=$SAReqHits)) {
-    $IsItSpam = 1;
-  } else {
-    $IsItSpam = 0;
-  }
-  $HighScoreVal = MailScanner::Config::Value('highspamassassinscore',$Message);
-  if ($SAHits && $HighScoreVal>0 && ($SAHits+$GSHits>=$HighScoreVal)) {
-    $IsItHighScore = 1;
-  } else {
-    $IsItHighScore = 0;
-  }
+  #if ($SAHits && ($SAHits+$GSHits>=$SAReqHits)) {
+  #  $IsItSpam = 1;
+  #} else {
+  #  $IsItSpam = 0;
+  #}
+  #$HighScoreVal = MailScanner::Config::Value('highspamassassinscore',$Message);
+  #if ($SAHits && $HighScoreVal>0 && ($SAHits+$GSHits>=$HighScoreVal)) {
+  #  $IsItHighScore = 1;
+  #} else {
+  #  $IsItHighScore = 0;
+  #}
   #print STDERR "Check 3, is \"" . $Test->{conf}->{report_template} . "\"\n";
+  ($IsItSpam, $IsItHighScore) = SATest_spam( $Message, $GSHits, $SAHits );
+
   return ($IsItSpam, $IsItHighScore, $SAHitList, $SAHits, $SAReport);
 }
 
+#
+# Subroutine to calculate whether the mail is SPAM or not
+#
+sub SATest_spam
+{
+	my ( $Message, $GSHits, $SAHits ) = @_;
+	my ( $IsItSpam, $IsItHighScore ) = (0,0);
+
+	my $SAReqHits = 0.0 + MailScanner::Config::Value(
+		'reqspamassassinscore', $Message
+	);
+	if ( $SAHits && ($SAHits+$GSHits >= $SAReqHits) )
+	{
+		$IsItSpam = 1;
+	}
+
+	my $HighScoreVal = 0.0 + MailScanner::Config::Value(
+		'highspamassassinscore', $Message
+	);
+	if ( $SAHits && $HighScoreVal>0 && ($SAHits+$GSHits >= $HighScoreVal) )
+	{
+		$IsItHighScore = 1;
+	}
+
+	return ( $IsItSpam, $IsItHighScore );
+}
+
+
 sub SATest {
   my($GSHits, $Test, $Mail, $Message) = @_;
 
