@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Sendmail.pm 3729 2006-09-24 15:47:39Z sysjkf $
+#   $Id: Sendmail.pm 3825 2007-01-29 18:45:33Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3729 $, 10;
+$VERSION = substr q$Revision: 3825 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -688,24 +688,36 @@ my($sed) = "/bin/sed";
   }
 
 
+  # This now takes a hash of queues --> space-separated list of message ids
   sub KickMessage {
-    my(@ids) = @_;
+    my($messages) = @_;
+    my @ids;
     my $args = '';
 
-    # Null addresses may cause a complete queue run!
-    my($ids, $id);
-    $ids = '';
-    foreach $id (@ids) {
-      $ids .= " -qI$id" if $id;
-    }
+    my $background = MailScanner::Config::Value('deliverinbackground');
 
-    if ($ids) {
-      my $outqdir = MailScanner::Config::Value('outqueuedir');
-      $args = " -OQueueDirectory=$outqdir " if $outqdir;
-      $args .= $ids;
-      $args .= ' &' if MailScanner::Config::Value('deliverinbackground');
-      #print STDERR "About to do \"" . MailScanner::Config::Value('sendmail2') . $args . "\"\n";
-      system(MailScanner::Config::Value('sendmail2') . $args);
+    my(@ThisBatch, $queue);
+    foreach $queue (keys %$messages) {
+      next unless $queue;
+      # Pull off blocks of 30 messages from the current queue
+      @ids = split(" ", $messages->{$queue});
+      while(@ids) {
+        @ThisBatch = splice @ids, $[, 30;
+
+        # Null addresses may cause a complete queue run!
+        my($ids, $id);
+        $ids = '';
+        foreach $id (@ThisBatch) {
+          $ids .= " -qI$id" if $id;
+        }
+
+        if ($ids) {
+          $args = " -OQueueDirectory=$queue " if $queue;
+          $args .= $ids;
+          $args .= ' &' if $background;
+          system(MailScanner::Config::Value('sendmail2') . $args);
+        }
+      }
     }
   }
 
