@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SweepContent.pm 3684 2006-08-03 21:49:18Z sysjkf $
+#   $Id: SweepContent.pm 3698 2006-08-23 09:25:31Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use DirHandle;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3684 $, 10;
+$VERSION = substr q$Revision: 3698 $, 10;
 
 # Attributes are
 #
@@ -128,7 +128,8 @@ sub ScanBatch {
       MailScanner::Log::WarnLog("Content Checks: Message %s is bigger than " .
                                 "%d bytes", $message->{id}, $maxmessagesize);
       $message->{otherreports}{""} .=
-        MailScanner::Config::LanguageValue($message, 'toobig') . "\n";
+        MailScanner::Config::LanguageValue($message, 'toobig') . ": " .
+                                           $message->{size} . " bytes\n";
       $message->{othertypes}{""} .= "s";
       $message->{sizeinfected}++;
       $counter++;
