@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ZMDiskStore.pm 3743 2006-10-09 15:42:09Z sysjkf $
+#   $Id: ZMDiskStore.pm 3831 2007-01-30 11:46:00Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ use MailScanner::Config;
 use vars qw($VERSION @DeletesPending);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3743 $, 10;
+$VERSION = substr q$Revision: 3831 $, 10;
 
 # List of pending delete operations so we can clear up properly when killed
 @DeletesPending = ();
@@ -64,7 +64,7 @@ $VERSION = substr q$Revision: 3743 $, 10;
 #use vars qw($VERSION);
 #
 #### The package version, both in 1.23 style *and* usable by MakeMaker:
-#$VERSION = substr q$Revision: 3743 $, 10;
+#$VERSION = substr q$Revision: 3831 $, 10;
 
 # Attributes are
 #
@@ -490,7 +490,7 @@ sub new {
     #$self={ _hdpathname => $hdpathname, 
     $self={ 
             _handle     => $handle,
-            _startpos   => -1 };
+            _startpos   => "-UNDEF-" };
 
     bless $self, $type;
   } else {
@@ -504,7 +504,7 @@ sub new {
 sub Start {
   #my ( $this )=@_;
   my ($this,$entiremessage )=@_;
-  if( $$this{_startpos} == -1 ) {
+  if( $$this{_startpos} == "-UNDEF-" ) {
     seek $$this{_handle}, 0, 0; # reset the handle
     my $InHeader = 0;
     #print STDERR "Start\n";
@@ -531,7 +531,7 @@ sub Start {
 sub Next {
   my ( $this )=@_;
        
-  if( $$this{_startpos} == -1 ) {
+  if( $$this{_startpos} == "-UNDEF-" ) {
     $this->Start();
   }
   return( $$this{_handle}->getline );
@@ -540,7 +540,7 @@ sub Next {
 sub Done {
   my ( $this )=@_;
   undef $$this{_handle};
-  $$this{_startpos} = -1;
+  $$this{_startpos} = "-UNDEF-";
 }
 
 1;
